{pkgs, ...}: {
  imports = [
    ./programs
    ./services
    ./shell
    ./wayland
    ./email.nix
    ./lf
    ./neovim
  ];

  home = {
    username = "tacocat";
    homeDirectory = "/home/tacocat";
    stateVersion = "24.05";
    sessionVariables = {
      EDITOR = "nvim";
      BAT_THEME = "ansi";
      DOTNET_ROOT = "$HOME/.dotnet";
    };
    sessionPath = [
      "$HOME/.local/bin"
      "$HOME/.dotnet"
    ];
    packages = with pkgs; [
      matlab
      octave
      mpv
      krita
      notesnook
      tree
      gimp
      r2modman
      rtorrent
      prismlauncher
      wireguard-tools
      spotify
      xournalpp
      cardinal
      vcv-rack
      tor-browser
      discord
      libreoffice
      notify-desktop
      libsixel
      aspell
      aspellDicts.en
      qalculate-qt
      zathura
      wineWowPackages.waylandFull
      comic-mono
      maple-mono
      jetbrains-mono
      fira-code
      mononoki
      inter
      (nerdfonts.override {fonts = ["FiraCode"];})
      pandoc
      pdftk
      git
      lua
      python3
      pamixer
      networkmanagerapplet
      htop
      p7zip
      cachix
      aria
      fastfetch
      gcc
      gcc-arm-embedded-13
      gnumake
      webcord
    ];
  };

  programs.nix-index.enable = true;

  # programs.gpg = {
  #   enable = true;
  # };

  fonts.fontconfig.enable = true;

  news.display = "silent";

  xdg = {
    enable = true;
    mimeApps = {
      enable = true;
      defaultApplications = {
        "application/pdf" = ["org.pwmt.zathura-pdf-mupdf.desktop"];
      };
    };
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  # ------------ GTK ------------

  gtk = {
    enable = true;
    theme = {
      package = pkgs.rose-pine-gtk-theme;
      name = "oomox-rose-pine-moon";
    };
    iconTheme = {
      package = pkgs.papirus-icon-theme;
      name = "Papirus";
    };
  };
}
